@@ -28,9 +28,9 @@
 // ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 // WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 //-------------------------------------------------------------------------
-use std::fmt;
-use std::ops::{Add, Mul, Div, Sub, AddAssign, SubAssign, Neg};
-use std::ops::{Deref, DerefMut, Index, IndexMut};
+use core::fmt;
+use core::ops::{Add, Mul, Div, Sub, AddAssign, SubAssign, Neg};
+use core::ops::{Deref, DerefMut, Index, IndexMut};
 
 use num::{Float, Num, One, Zero, Signed};
 
@@ -60,7 +60,7 @@ impl<T> M66<T> {
 }
 
 
-impl<T: Float + std::iter::Sum> LinearAlgebra<T> for M66<T> {
+impl<T: Float + core::iter::Sum> LinearAlgebra<T> for M66<T> {
     #[inline]
     fn rows(&self) -> usize {
         self.0.len()
@@ -937,7 +937,7 @@ impl<T: Float + std::iter::Sum> LinearAlgebra<T> for M66<T> {
                 q[i] = q_tilde;
             }
             // TODO(elsuizo:2020-08-05): do this with a another for loop
-            let basis = V6::new([q[0], q[1], q[2], q[3], q[4], q[5]]);
+            let basis = V6::new_from(q[0], q[1], q[2], q[3], q[4], q[5]);
             let q     = M66::new_from_vecs(basis);
             let r     = q.transpose() * (*self);
             Some((q, r))
@@ -1884,7 +1884,6 @@ macro_rules! m66_new {
 //-------------------------------------------------------------------------
 impl<T: Num + fmt::Display> fmt::Display for M66<T> {
     fn fmt(&self, dest: &mut fmt::Formatter) -> fmt::Result {
-        println!();
         write!(
             dest,
             "|{0:<7.2} {1:^7.2} {2:^7.2} {3:^7.2} {4:^7.2} {5:>7.2}|\n",
